# Base AI Capabilities
### On this page
  * [Inventory AI Prompts](https://help.sap.com/docs/leanix/ea/base-ai-capabilities#inventory-ai-prompts)
  * [Using the Inventory AI Prompts](https://help.sap.com/docs/leanix/ea/base-ai-capabilities#using-the-inventory-ai-prompts)
  * [AI-Assisted Text](https://help.sap.com/docs/leanix/ea/base-ai-capabilities#ai-assisted-text)
  * [AI-Generated Context](https://help.sap.com/docs/leanix/ea/base-ai-capabilities#ai-generated-context)
  * [AI-Supported Translation](https://help.sap.com/docs/leanix/ea/base-ai-capabilities#ai-supported-translation)


SAP LeanIX base AI capabilities make enterprise architecture data more accessible and actionable, offering natural language queries, AI-assisted text generation, contextual insights, and translation support.
